/*
    ************************************************
    folderHorizon search.js > fuse.j
    ************************************************
*/

var showArchiveSource = false,
    debug = false,
    searchInput = document.getElementById('searchInput'),
    searchButton = document.getElementById('searchButton'),
    searchMessage = document.getElementById('searchMessage'),
    searchResult = document.getElementById('searchResult'),
    minInputChars = 3,
    options = {
        includeMatches: true,
        findAllMatches: true,
        minMatchCharLength: minInputChars, // Use input!
        threshold: 0.6, // Default 0.6 :: 0.0 requires a perfect match, 1.0 would match anything
        useExtendedSearch: true,
        ignoreLocation: true,
        keys: ['text', 'tags', 'captions']
    },
    UL = '<ul>',
    ULend = '</ul><br>',
    LI = '<li>',
    LInodot = '<li class="nodot">',
    LIend = '</li>';;

searchInput.addEventListener('keypress', function (event) {
    if (event.key === 'Enter') {
        event.preventDefault();
        searchButton.click();
    }
});

searchButton.addEventListener('click', function () {
    searchMessage.textContent = '';
    searchResult.textContent = '';

    if (searchInput.value.length < minInputChars) {
        searchMessage.textContent = 'min ' + minInputChars + ' chars!'
        return
    }

    // Use input!
    options.minMatchCharLength = searchInput.value.length;

    var fuse = new Fuse(searchdata, options),
        result = fuse.search(searchInput.value);

    if (result.length < 1) {
        searchMessage.textContent = 'not found';
    } else {
        var more = '';
        if (result.length > 1) more = 's';
        searchMessage.textContent = ' found in ' + result.length + ' page' + more;
        printResult(result);
        if (debug) document.getElementById('searchDebug').textContent = JSON.stringify(result, null, 4);
    }
});

function printResult(res) {
    for (var i = 0; i < res.length; i++) {
        var div = document.createElement('div'),
            keys = res[i].matches,
            text = [],
            tags = [],
            captions = [];

        // Page href
        div.innerHTML += '<p>Page <a href="' + res[i].item.href + '" target="_blank" class="link-result">' + res[i].item.href + '</a></p>';

        // Load matches
        for (var k = 0; k < keys.length; k++) {
            if (keys[k].key === 'text') text.push(keys[k].value);
            if (keys[k].key === 'tags') tags.push(keys[k].value);
            if (keys[k].key === 'captions') {
                var caption = {
                    value: keys[k].value,
                    source: res[i].item.source[keys[k].refIndex]
                }
                captions.push(caption);
            }
        }

        // page text matches
        if (text.length > 0) {
            div.innerHTML += UL + 'Text';
            for (var p = 0; p < text.length; p++) {
                div.innerHTML += LInodot + '[... ' + text[p] + ' ...]' + LIend;
            }
            div.innerHTML += ULend;
        }

        // page tags matches
        if (tags.length > 0) {
            div.innerHTML += '<b>Tags</b>';
            for (var t = 0; t < tags.length; t++) {
                div.innerHTML += ' #' + tags[t] + LIend;
            }
            div.innerHTML += '<br><br>';
        }

        // file captions matches
        if (captions.length > 0) {
            div.innerHTML += UL + 'File captions';
            for (var c = 0; c < captions.length; c++) {
                if (showArchiveSource) {
                    div.innerHTML += LI + captions[c].value + '<br><b>[source file]</b> ' + captions[c].source + LIend;
                } else {
                    div.innerHTML += LI + captions[c].value + LIend;
                }
            }
            div.innerHTML += ULend;
        }

        // Print
        div.classList.add('search-result');
        searchResult.appendChild(div);
    }
}